#!/usr/bin/perl

=head1 NAME

Debconf::Element::Noninteractive::Password - dummy password Element

=cut

package Debconf::Element::Noninteractive::Password;
use warnings;
use strict;
use base qw(Debconf::Element::Noninteractive);

=head1 DESCRIPTION

This is a dummy password element.

=cut

1
